@@ -9,6 +9,17 @@ from netsuite.Netsuite import Netsuite
 from netsuite.settings import api_settings, IN_MEMORY_STORAGE, JSON_STORAGE
 from OpenSSL.SSL import FILETYPE_PEM
 from OpenSSL.crypto import (dump_certificate, X509, X509Name, PKey, TYPE_RSA, X509Req, dump_privatekey, X509Extension)
+from rich import print
+
+def link(uri, label=None):
+    if label is None:
+        label = uri
+    parameters = ''
+
+    # OSC 8 ; params ; URI ST <name> OSC 8 ;; ST
+    escape_mask = '\033]8;{};{}\033\\{}\033]8;;\033\\'
+
+    return escape_mask.format(parameters, uri, label)
 
 @click.group()
 def cli():
@@ -17,6 +28,58 @@ def cli():
     """
     pass
 
+@cli.command()
+def initialize():
+    steps_completed = False
+    while not steps_completed:
+        steps_completed = prompt(f"Have you created the integration record by following the steps in the README?", default='y', type=click.BOOL, show_choices=True)
+        if steps_completed:
+            client_id = prompt("Client Id", hide_input=False)
+        else:
+            print('Read it and do the steps hoe https://bitbucket.org/theapiguys/netsuite_python/src/master/')
+
+    print("Generate Certificate", )
+    certificate_uploaded = False
+    while not certificate_uploaded:
+        certificate_uploaded = prompt(f"Have you generated a certificate?", default='y', type=click.BOOL, show_choices=True)
+        if certificate_uploaded:
+            certificate_id = prompt("Certificate ID: ", hide_input=False)
+        else:
+            generate_certificate()
+
+    netsuite_app_name = prompt("What is the netsuite application name? (Portion before app.netsuite.com)", hide_input=False)
+
+    app_name = prompt("App Name", default=api_settings.APP_NAME)
+    allow_none = prompt("Allow None", default=api_settings.ALLOW_NONE)
+    use_datetime = prompt("Use Datetime", default=api_settings.USE_DATETIME)
+    storage_class = prompt("Storage Class", default=api_settings.defaults.get('STORAGE_CLASS'),
+                           type=click.Choice(api_settings.defaults.get('DEFAULT_STORAGE_CLASSES')),
+                           show_choices=True)
+
+    creds = {
+        'CLIENT_ID': client_id,
+        'CERT_ID': cert_id,
+        # 'CLIENT_SECRET': client_secret,
+        # 'REDIRECT_URL': redirect_url,
+        'NETSUITE_APP_NAME': netsuite_app_name,
+        'APP_NAME': app_name,
+        'ALLOW_NONE': allow_none,
+        'USE_DATETIME': use_datetime,
+        'STORAGE_CLASS': storage_class,
+    }
+
+    if storage_class == JSON_STORAGE:
+        creds['JSON_STORAGE_PATH'] = prompt("Token Storage File", default=api_settings.JSON_STORAGE_PATH,
+                                            type=click.Path(readable=True, writable=True))
+
+    with open(api_settings.CREDENTIALS_PATH, 'w') as f:
+        creds_json = json.dumps(creds, indent=4)
+        f.write(creds_json)
+        print(f"Netsuite Credentials written to: {api_settings.CREDENTIALS_PATH}")
+
+
+
+
 
 @cli.command()
 def generate_certificate():
@@ -113,6 +176,10 @@ def generate_client_config():
 
     return creds
 
+@cli.command()
+def generate_rest_client():
+    netsuite = Netsuite()
+    netsuite.generate_rest_client()
 
 @cli.command()
 @click.option('--credentials-file', '--f', type=click.File('r'), default=api_settings.CREDENTIALS_PATH,
